@@ -14,35 +14,35 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the
- * Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
 
-#include <time.h>
-#include <string.h>
- 
-#include <glib/gi18n.h>
- 
-#include "egg-datetime.h"
-
-#include "seahorse-common.h"
-#include "seahorse-passphrase.h"
-#include "seahorse-progress.h"
-#include "seahorse-util.h"
-#include "seahorse-widget.h"
+#include "seahorse-gpgme-dialogs.h"
 
 #include "seahorse-pgp.h"
 #include "seahorse-pgp-backend.h"
 #include "seahorse-gpgme.h"
-#include "seahorse-gpgme-dialogs.h"
 #include "seahorse-gpgme-key.h"
 #include "seahorse-gpgme-key-op.h"
 #include "seahorse-gpgme-keyring.h"
 
+#include "seahorse-common.h"
+
+#include "libegg/egg-datetime.h"
+
+#include "libseahorse/seahorse-passphrase.h"
+#include "libseahorse/seahorse-progress.h"
+#include "libseahorse/seahorse-util.h"
+#include "libseahorse/seahorse-widget.h"
+
+#include <glib/gi18n.h>
+
+#include <string.h>
+#include <time.h>
+
 /**
  * SECTION:seahorse-gpgme-generate
  * @short_description: This file contains creation dialogs for pgp key creation.
