@@ -14,22 +14,21 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the
- * Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
 
 #include "seahorse-combo-keys.h"
-#include "seahorse-common.h"
-#include "seahorse-object-widget.h"
-#include "seahorse-util.h"
+#include "seahorse-gpgme-dialogs.h"
+#include "seahorse-gpgme-key-op.h"
+#include "seahorse-pgp-keysets.h"
 
-#include "pgp/seahorse-gpgme-dialogs.h"
-#include "pgp/seahorse-gpgme-key-op.h"
-#include "pgp/seahorse-pgp-keysets.h"
+#include "seahorse-common.h"
+
+#include "libseahorse/seahorse-object-widget.h"
+#include "libseahorse/seahorse-util.h"
 
 #include <glib/gi18n.h>
 
