@@ -14,9 +14,8 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * License along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -29,9 +28,10 @@
 #include "seahorse-unknown-source.h"
 
 #include "seahorse-common.h"
-#include "seahorse-progress.h"
-#include "seahorse-servers.h"
-#include "seahorse-util.h"
+
+#include "libseahorse/seahorse-progress.h"
+#include "libseahorse/seahorse-servers.h"
+#include "libseahorse/seahorse-util.h"
 
 #include <glib/gi18n.h>
 
@@ -310,6 +310,8 @@ seahorse_pgp_backend_initialize (void)
 	g_object_unref (self);
 
 	g_return_if_fail (pgp_backend != NULL);
+
+	gpgme_set_engine_info (GPGME_PROTOCOL_OpenPGP, GNUPG, NULL);
 }
 
 SeahorseGpgmeKeyring *
